@@ -33,6 +33,8 @@ G_BEGIN_DECLS
 #define ICON_HEIGHT 10
 #define ICON_WIDTH  40
 
+extern const int icon_list_count;
+
 typedef struct _DriveData DriveData;
 
 struct _DriveData
@@ -57,10 +59,18 @@ struct _DriveData
 	gchar *custom_icon_out;
 
 	GtkWidget *error_dialog;
+	GtkWidget *about_dialog;
+	GtkWidget *prop_dialog;
 };
 
 void redraw_pixmap(DriveData *dd);
 void start_callback_update(DriveData *dd);
+GtkWidget* hig_dialog_new (GtkWindow      *parent,
+			   GtkDialogFlags flags,
+			   GtkMessageType type,
+			   GtkButtonsType buttons,
+			   const gchar    *header,
+			   const gchar    *message);
 
 G_END_DECLS
 #endif
